<?php namespace EscapeWork\Manager;

use \Controller;
use \View;
use \Input;
use \Redirect;
use \Msg;
use \Config;
use \Auth;
use \Hash;
use \Request;

class UserController extends Controller
{

    public function index()
    {
        $view        = View::make('manager::users.index');
        $view->users = User::all();

        return $view;
    }

    public function create()
    {
        Msg::setInfo('Inserindo um novo usuário');

        $user       = new User();
        $user->setDataFromArray(Input::old());

        $view       = View::make('manager::users.form');
        $view->user = $user;
        $view->edit = false;
        $view->extraFields = Config::get('manager::extra_fields.User');

        return $view;
    }

    public function store()
    {
        $fields = Input::all();

        if (User::validate($fields) === false) {
            return Redirect::to(Config::get('manager::url') . '/usuarios/create')
                    ->withInput()
                    ->withErrors(User::$messages);
        }

        $password           = isset($fields['password']) ? $fields['password'] : '';
        $fields['password'] = Hash::make($password);
        $user = User::create($fields);

        return Redirect::to( Config::get('manager::url') . '/usuarios' )->with('message', 'O usuário <strong>' . $user->name . '</strong> foi inserido com sucesso!');
    }

    public function show($id)
    {
        if (Request::ajax()) {
            return User::find($id);
        } else {
            return Redirect::to(Config::get('manager::url') . '/usuarios');
        }
    }

    public function edit($id)
    {
        if (! $user = User::find($id)) {
            return Redirect::to(Config::get('manager::url') . '/usuarios')
                    ->with('error', 'Usuário não encontrado');
        }

        Msg::setInfo('Editando o usuário <strong>'.$user->name.'</strong>');

        $view              = View::make('manager::users.form');
        $view->edit        = true;
        $view->user        = $user;
        $view->extraFields = Config::get('manager::extra_fields.User');
        
        return $view;
    }

    public function update($id)
    {
        if (! $user = User::find($id)) {
            return Redirect::to( Config::get('manager::url') . '/usuarios' )
                    ->with('error', 'Usuário não encontrado');
        }

        # forçando a validação a ignorar o id passado
        User::$validationRules['email']['unique'] = 'unique:users,email,' . $user->id;

        # validando
        $fields = Input::except('_method', 'password');
        if (($password = Input::get('password')) != '')
        {
            $fields['password'] = Hash::make($password);
        }

        if (User::validate($fields) == false) {
            return Redirect::to(Config::get('manager::url') . '/usuarios/' . $id . '/edit')
                            ->withInput()
                            ->withErrors( User::$messages );
        }

        # atualizando no banco
        $user->setDataFromArray($fields);
        $user->save();

        return Redirect::to(Config::get('manager::url') . '/usuarios')
                ->with('message', 'O usuário <strong>'. $user->name .'</strong> foi editado com sucesso!'); 
    }

    public function destroy($id)
    {
        if (! $user = User::find($id)) {
            return Redirect::to(Config::get('manager::url') . '/usuarios')
                    ->with('error', 'Usuário não encontrado');
        }

        # verificando se o usuário logado não está tentando se excluir
        if (Auth::check() && $user->id == Auth::user()->id) {
            return Redirect::to(Config::get('manager::url') . '/usuarios')
                    ->with('error', '<strong>'.$user->name.'</strong>, não é possível excluir o seu próprio usuário');
        }

        $user->delete();

        return Redirect::to(Config::get('manager::url') . '/usuarios')
                ->with('message', 'O usuário <strong>'.$user->name.'</strong> foi excluído com sucesso!');
    }
}